==> nextcloud-app-calendar-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
    "Open »%s«" : "Åbn »%s«",
    "Cheers!" : "Hav en fortsat god dag.",
    "Recipient" : "Modtager",
    "URL violates local access rules" : "URL i modstrid med lokale adgangsregler",
    "The remote server did not give us access to the calendar (HTTP 404 error)" : "Serveren gav ikke adgang til kalenderen (HTTP 404 fejl)",
    "Too many redirects. Aborting ..." : "For mange omdirigeringer. Afbryder ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveren gav os ikke adgang til kalenderen (HTTP {%s} fejl)",
    "Error connecting to remote server" : "Fejl ved forbindelse til serveren",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fejl efter anmodning fra serveren. Dette er muligvis relateret til ikke ens certifikater",
    "Error requesting resource on remote server" : "Fejl efter anmodning fra server",
    "Individual" : "Individuelt",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Lokale",
    "Unknown" : "Ukendt",
    "Required" : "Krævet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltager ikke",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
    "Please create a calendar first." : "Opret venligst en kalender først",
    "New event" : "Opret begivenhed",
    "CalDAV address for clients" : "CalDAV addresse for klienter",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "Could not save WebCal-calendar" : "Kunne gemme WebCal-kalender",
    "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
    "Email sent." : "Email afsendt.",
    "Could not send your email." : "Kunne ikke afsende din email.",
    "group" : "gruppe",
    "circle" : "cirkel",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindelser",
    "Repeating" : "Gentagende",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig prøve",
    "Cancelled" : "Annulléret",
    "Please add a title." : "Indtast venligst en titel.",
    "Please select a calendar." : "Vælg venligst en kalender.",
    "The event can not end before it starts." : "Begivenheden kan ikke stoppe før den starter",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uge",
    "Every month" : "Hver måmned",
    "Every year" : "Hvert år",
    "never" : "aldrig",
    "after" : "efter",
    "Automatic ({timezone})" : "Automatisk ({timezone})",
    "How about getting started by importing some calendars?" : "Hvad med at starte med at importere nogle kalendere?",
    "At time of event" : "På tidspunktet for begivenheden",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Valgfrit",
    "Audio" : "Lyd",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min.",
    "hours" : "timer",
    "days" : "dage",
    "week" : "uge",
    "before" : "før",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Successfully imported {imported} objects" : "{imported} objekter importeret korrekt",
    "Imported {imported} out of {all}, skipped one duplicate" : "Importerede {imported} ud af {all}, udelod 1, der lå dobbelt",
    "Imported {imported} out of {all}, one failure" : "Importerede {imported} ud af {all}, én fejlede",
    "Imported {imported} out of {all}, {errors} failures" : "Importerede {imported} ud af {all}, {errors} fejlede",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importerede {imported} ud af {all}, udelod {duplicates}, der lå dobbelt",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Importerede {imported} ud af {all}, {errors} fejlede, udelod {duplicates}, der lå dobbelt",
    "Audio alarm {time} before the event starts" : "Alarm {time} før begivenheden starter",
    "Pop-up {time} before the event starts" : "Pop-up {time} før begivenheden starter",
    "Email {time} before the event starts" : "Email {time} før begivenheden starter",
    "None {time} before the event starts" : "Intet {time} før begivenheden starter",
    "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
    "Audio alarm {time} before the event ends" : "Alarm {time} før begivenheden slutter",
    "Pop-up {time} before the event ends" : "Pop-up {time} før begivenheden slutter",
    "Email {time} before the event ends" : "Email {time} før begivenheden slutter",
    "None {time} before the event ends" : "Intet {time} før begivenheden starter",
    "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
    "Audio alarm {time} after the event starts" : "Alarm {time} efter at begivenheden starter",
    "Pop-up {time} after the event starts" : "Pop-up {time} efter at begivenheden starter",
    "Email {time} after the event starts" : "Email {time} efter at begivenheden starter",
    "None {time} after the event starts" : "Intet {time} efter at begivenheden starter",
    "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
    "Audio alarm {time} after the event ends" : "Alarm {time} efter begivenheden slutter",
    "Pop-up {time} after the event ends" : "Pop-up {time} efter begivenheden slutter",
    "Email {time} after the event ends" : "Email {time} efter begivenheden slutter",
    "None {time} after the event ends" : "Intet {time} efter begivenheden slutter",
    "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
    "Audio alarm at the event's start" : "Alarm ved begivenhedens start",
    "Pop-up at the event's start" : "Pop-up ved begivenhedens start",
    "Email at the event's start" : "Email ved begivenhedens start",
    "None at the event's start" : "Intet ved begivenhedens start",
    "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
    "Audio alarm at the event's end" : "Alarm ved begivenhedens afslutning",
    "Pop-up at the event's end" : "Pop-up ved begivenhedens afslutning",
    "Email at the event's end" : "Email ved begivenhedens afslutning",
    "None at the event's end" : "Intet ved begivenhedens afslutning",
    "{type} at the event's end" : "{type} ved begivenhedens slutning",
    "Audio alarm at {time}" : "Alarm {time}",
    "Pop-up at {time}" : "Pop-up {time}",
    "Email at {time}" : "Emai {time}",
    "None at {time}" : "Intet {time}",
    "{type} at {time}" : "{type} på {time}",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Please enter a valid WebCal-URL" : "Angiv en gyldig WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Alvorlig fejl i webcal proxy. Kontakt venligst administratoren for mere information.",
    "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events.\n* 🙈 **We’re not reinventing the wheel!** Based on the great [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalender-appen er brugerfladen for Nextclouds CalDAV-server. Synkroniser ubesværet begivenheder på tværs af enheder med Nextcloud og rediger dem online.\n\n* 🚀 **Integration med andre Nextcloud-apps!** Indtil videre Kontakt-app'en - flere på vej.\n* 🌐 **WebCal-understøttelse!** Vil du se dit favoritholds kampe i kalenderen? Intet problem!\n* 🙋 **Deltagere!** Inviter andre til dine begivenheder.\n* 🙈 **Vi genopfinder ikke hjulet!** Baseret på de fantastiske [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) og [fullcalendar](https://github.com/fullcalendar/fullcalendar)-systemer.",
    "Title of the Event" : "Titel på begivenheden",
    "Starts" : "Starter",
    "Ends" : "Slutter",
    "All day Event" : "Heldagsbegivenhed",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "More ..." : "Mere...",
    "Create" : "Ny",
    "Update" : "Opdatér",
    "Close" : "Luk",
    "Location" : "Placering",
    "Description" : "Beskrivelse",
    "Event status" : "Begivenhedens status",
    "Visibility when sharing" : "Synlighed ved deling",
    "Export" : "Eksportér",
    "%s has published the calendar %s" : "%s har offentliggjort kalenderen %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen {boldstart}%s{boldend}.",
    "Click here to access it" : "Klik her for at få adgang til den",
    "We wanted to inform you that %s has published the calendar %s." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen %s.",
    "Click on the link below to access it" : "Klik på linket under for at få adgang til den",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Today" : "I dag",
    "More" : "Mere",
    "Edit" : "Redigér",
    "Link" : "Link",
    "iCal link" : "iCal link",
    "Download" : "Hent",
    "Share with users, groups or circles" : "Del med brugere, grupper eller circler",
    "can edit" : "kan redigere",
    "Share link" : "Del link",
    "Public access" : "Offentlig adgang",
    "Email link to person" : "E-mail link til person",
    "Send" : "Send",
    "New Calendar" : "Ny kalender",
    "Name" : "Navn",
    "New Subscription" : "Tilføj abonnement",
    "Go back" : "Gå tilbage",
    "Go forward" : "Gå frem",
    "Calendar does not exist" : "Kalenderen eksisterer ikke",
    "Maybe you got a wrong link or the calendar was unshared?" : "Måske har du fået et forkert link eller delingen af kalenderen er blevet fjernet",
    "Edit event" : "Rediger begivenhed",
    "Delete Event" : "Slet begivenhed",
    "Save Event" : "Gem begivenhed",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolut",
    "Repeat" : "Gentag",
    "times every" : "gange hver",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Email-påmindelser er ikke implementeret i CalDAV-serveren endnu, så de vil ikke blive sendt.",
    "Add" : "Tilføj",
    "Email address of attendee" : "E-mail på deltager",
    "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
    "Reset repeating rule" : "Nulstil gentagelsesregel",
    "Repeat every ..." : "Gentag hver ...",
    "end repeat ..." : "stop gentagelse ...",
    "times" : "gange",
    "Import Calendars" : "Importer kalenderere",
    "Import canceled" : "Importering annulleret",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
    "New calendar" : "Ny kalender",
    "File is empty" : "Fil er tom",
    "File could not be parsed" : "Filen kunne ikke læses",
    "Import scheduled" : "Importering planlagt",
    "%s shared the calendar <strong>%s</strong> with you" : "%s delte kalenderen <strong>%s</strong> med dig",
    "Embed" : "Embed",
    "Iframe to integrate" : "Iframe der skal integreres",
    "Publish URL" : "Offentliggør URL",
    "Settings & import" : "Indstillinger & importer",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
    "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
    "Show week numbers" : "Vis ugenummer ",
    "Timezone" : "Tidszone",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/macOS CalDAV address" : "iOS/macOS CalDAV-adresse",
    "Subscribe" : "Tilmeld"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
    "Open »%s«" : "Åbn »%s«",
    "Cheers!" : "Hav en fortsat god dag.",
    "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Download" : "Hent",
    "Delete" : "Slet",
    "Share link" : "Del link",
    "Delete share link" : "Slet delingslink",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "can edit" : "kan redigere",
    "New calendar" : "Ny kalender",
    "Filename" : "Filnavn",
    "Cancel" : "Annullér",
    "Automatic" : "Automatisk",
    "Show week numbers" : "Vis ugenummer ",
    "Settings & import" : "Indstillinger & importer",
    "Notification" : "Notifikation",
    "Email" : "E-mail",
    "Busy" : "Optaget",
    "Unknown" : "Ukendt",
    "All day" : "Hele dagen",
    "from" : "fra",
    "to" : "til",
    "never" : "aldrig",
    "after" : "efter",
    "Repeat" : "Gentag",
    "Monday" : "Mandag",
    "Summary" : "Oversigt",
    "More" : "Mere",
    "Save" : "Gem",
    "Update" : "Opdatér",
    "Select Date" : "Vælg dato",
    "Personal" : "Personlig",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindelser",
    "Activity" : "Aktivitet",
    "Close" : "Luk",
    "Anniversary" : "Årsdag",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Untitled event" : "Unavngiven begivenhed",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Status" : "Status",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig",
    "Cancelled" : "Annulléret",
    "Categories" : "Kategorier",
    "Presentation" : "Præsentation",
    "Office" : "Kontor",
    "Mail" : "Mail",
    "Play" : "Afspil",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
